@@ -76,26 +76,27 @@ public class Pipe {
 	public void managePipe(ErrorStatus error) throws IOException {
 		final boolean noStdErr = option.isPipeNoStdErr();
 
-		for(String source = readFirstDiagram(); source != null; source = readSubsequentDiagram()) {
+		for (String source = readFirstDiagram(); source != null; source = readSubsequentDiagram()) {
 			final Defines defines = option.getDefaultDefines();
 			final SFile newCurrentDir = option.getFileDir() == null ? null : new SFile(option.getFileDir());
 			final SourceStringReader sourceStringReader = new SourceStringReader(defines, source, UTF_8,
 					option.getConfig(), newCurrentDir);
 
-			if (option.isComputeurl()) {
+			if (option.isComputeurl())
 				computeUrlForDiagram(sourceStringReader);
-			} else if (option.isSyntax()) {
+			else if (option.isSyntax())
 				syntaxCheckDiagram(sourceStringReader, error);
-			} else if (option.isPipeMap()) {
+			else if (option.isPipeMap())
 				createPipeMapForDiagram(sourceStringReader, error);
-			} else {
+			else
 				generateDiagram(sourceStringReader, error, noStdErr);
-			}
+
 			ps.flush();
 		}
 	}
 
-	private void generateDiagram(SourceStringReader sourceStringReader, ErrorStatus error, boolean noStdErr) throws IOException {
+	private void generateDiagram(SourceStringReader sourceStringReader, ErrorStatus error, boolean noStdErr)
+			throws IOException {
 		final OutputStream os = noStdErr ? new ByteArrayOutputStream() : ps;
 		final DiagramDescription result = sourceStringReader.outputImage(os, option.getImageIndex(),
 				option.getFileFormatOption());
@@ -111,28 +112,27 @@ public class Pipe {
 				ps.write(baos.toByteArray());
 			}
 		}
-		if (option.getPipeDelimitor() != null) {
+		if (option.getPipeDelimitor() != null)
 			ps.println(option.getPipeDelimitor());
-		}
+
 	}
 
 	private void createPipeMapForDiagram(SourceStringReader sourceStringReader, ErrorStatus error) throws IOException {
-		final String result = sourceStringReader.getCMapData(option.getImageIndex(),
-				option.getFileFormatOption());
+		final String result = sourceStringReader.getCMapData(option.getImageIndex(), option.getFileFormatOption());
 		// https://forum.plantuml.net/10049/2019-pipemap-diagrams-containing-links-give-zero-exit-code
 		// We don't check errors
 		error.goOk();
-		if (result == null) {
+		if (result == null)
 			ps.println();
-		} else {
+		else
 			ps.println(result);
-		}
+
 	}
 
 	private void computeUrlForDiagram(SourceStringReader sourceStringReader) throws IOException {
-		for (BlockUml s : sourceStringReader.getBlocks()) {
+		for (BlockUml s : sourceStringReader.getBlocks())
 			ps.println(s.getEncodedUrl());
-		}
+
 	}
 
 	private void syntaxCheckDiagram(SourceStringReader sourceStringReader, ErrorStatus error) {
@@ -153,11 +153,11 @@ public class Pipe {
 
 	private void printInfo(final PrintStream output, final SourceStringReader sourceStringReader) {
 		final List<BlockUml> blocks = sourceStringReader.getBlocks();
-		if (blocks.size() == 0) {
+		if (blocks.size() == 0)
 			stdrpt.printInfo(output, null);
-		} else {
+		else
 			stdrpt.printInfo(output, blocks.get(0).getDiagram());
-		}
+
 	}
 
 	String readFirstDiagram() throws IOException {
@@ -174,14 +174,13 @@ public class Pipe {
 		final StringBuilder sb = new StringBuilder();
 
 		String line;
-		while(state != State.COMPLETE && (line = br.readLine()) != null) {
+		while (state != State.COMPLETE && (line = br.readLine()) != null) {
 
-			if(line.startsWith("@@@format ")) {
+			if (line.startsWith("@@@format ")) {
 				manageFormat(line);
 			} else {
-				if (state == State.NO_CONTENT && line.trim().length() > 0) {
+				if (state == State.NO_CONTENT && line.trim().length() > 0)
 					state = State.START_MARK_NOT_FOUND;
-				}
 
 				if (state == State.START_MARK_NOT_FOUND && line.startsWith("@start")) {
 					sb.setLength(0); // discard any previous input
@@ -191,38 +190,35 @@ public class Pipe {
 					state = State.COMPLETE;
 				}
 
-				if (state != State.NO_CONTENT) {
+				if (state != State.NO_CONTENT)
 					sb.append(line).append("\n");
-				}
+
 			}
 		}
 
-		switch(state) {
-			case NO_CONTENT:
-				return null;
-			case START_MARK_NOT_FOUND:
-				return (unmarkedAllowed) ? "@startuml\n" + sb.toString() + "@enduml\n" : null;
-			case START_MARK_FOUND:
-				return sb.toString() + expectedEnd;
-			case COMPLETE:
-				return sb.toString();
-			default:
-				throw new IllegalStateException("Unexpected value: " + state);
+		switch (state) {
+		case NO_CONTENT:
+			return null;
+		case START_MARK_NOT_FOUND:
+			return (unmarkedAllowed) ? "@startuml\n" + sb.toString() + "@enduml\n" : null;
+		case START_MARK_FOUND:
+			return sb.toString() + expectedEnd;
+		case COMPLETE:
+			return sb.toString();
+		default:
+			throw new IllegalStateException("Unexpected value: " + state);
 		}
 	}
 
 	void manageFormat(String s) {
-		if (s.contains("png")) {
+		if (s.contains("png"))
 			option.setFileFormatOption(new FileFormatOption(FileFormat.PNG));
-		} else if (s.contains("svg")) {
+		else if (s.contains("svg"))
 			option.setFileFormatOption(new FileFormatOption(FileFormat.SVG));
-		}
+
 	}
 
-	 enum State {
-		NO_CONTENT,
-		START_MARK_NOT_FOUND,
-		START_MARK_FOUND,
-		COMPLETE
+	enum State {
+		NO_CONTENT, START_MARK_NOT_FOUND, START_MARK_FOUND, COMPLETE
 	}
 }
