@@ -208,11 +208,6 @@ public class SkinParamDelegator implements ISkinParam {
 		return skinParam.getConditionEndStyle();
 	}
 
-	@Override
-	public double minClassWidth() {
-		return skinParam.minClassWidth();
-	}
-
 	@Override
 	public boolean sameClassWidth() {
 		return skinParam.sameClassWidth();
@@ -234,7 +229,7 @@ public class SkinParamDelegator implements ISkinParam {
 	}
 
 	@Override
-	public boolean useUnderlineForHyperlink() {
+	public UStroke useUnderlineForHyperlink() {
 		return skinParam.useUnderlineForHyperlink();
 	}
 
@@ -443,4 +438,9 @@ public class SkinParamDelegator implements ISkinParam {
 		return skinParam.getlengthAdjust();
 	}
 
+	@Override
+	public double getParamSameClassWidth() {
+		return skinParam.getParamSameClassWidth();
+	}
+
 }
