@@ -48,7 +48,6 @@ import java.util.Collections;
 import java.util.List;
 
 import net.sourceforge.plantuml.annotation.HaxeIgnored;
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.core.Diagram;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
@@ -61,7 +60,6 @@ import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 public class SourceStringReader {
 
 	final private List<BlockUml> blocks;
-	final private ThemeStyle style;
 
 	public SourceStringReader(String source) {
 		this(Defines.createEmpty(), source, Collections.<String>emptyList());
@@ -98,15 +96,9 @@ public class SourceStringReader {
 
 	public SourceStringReader(Defines defines, String source, Charset charset, List<String> config,
 			SFile newCurrentDir) {
-		this(defines, source, charset, config, newCurrentDir, ThemeStyle.LIGHT_REGULAR);
-	}
-
-	public SourceStringReader(Defines defines, String source, Charset charset, List<String> config, SFile newCurrentDir,
-			ThemeStyle style) {
-		this.style = style;
 		try {
-			final BlockUmlBuilder builder = new BlockUmlBuilder(style, config, charset, defines,
-					new StringReader(source), newCurrentDir, "string");
+			final BlockUmlBuilder builder = new BlockUmlBuilder(config, charset, defines, new StringReader(source),
+					newCurrentDir, "string");
 			this.blocks = builder.getBlockUmls();
 		} catch (IOException e) {
 			Log.error("error " + e);
@@ -136,11 +128,11 @@ public class SourceStringReader {
 
 	@Deprecated
 	public String generateImage(OutputStream os, FileFormatOption fileFormatOption) throws IOException {
-		return outputImage(os, fileFormatOption.withStyle(style)).getDescription();
+		return outputImage(os, fileFormatOption).getDescription();
 	}
 
 	public DiagramDescription outputImage(OutputStream os, FileFormatOption fileFormatOption) throws IOException {
-		return outputImage(os, 0, fileFormatOption.withStyle(style));
+		return outputImage(os, 0, fileFormatOption);
 	}
 
 	@Deprecated
@@ -154,12 +146,11 @@ public class SourceStringReader {
 
 	@Deprecated
 	public String generateImage(OutputStream os, int numImage, FileFormatOption fileFormatOption) throws IOException {
-		return outputImage(os, numImage, fileFormatOption.withStyle(style)).getDescription();
+		return outputImage(os, numImage, fileFormatOption).getDescription();
 	}
 
 	public DiagramDescription outputImage(OutputStream os, int numImage, FileFormatOption fileFormatOption)
 			throws IOException {
-		fileFormatOption = fileFormatOption.withStyle(style);
 		if (blocks.size() == 0) {
 			noStartumlFound(os, fileFormatOption);
 			return null;
@@ -184,10 +175,9 @@ public class SourceStringReader {
 	}
 
 	public DiagramDescription generateDiagramDescription(int numImage, FileFormatOption fileFormatOption) {
-		fileFormatOption = fileFormatOption.withStyle(style);
-		if (blocks.size() == 0) {
+		if (blocks.size() == 0)
 			return null;
-		}
+
 		for (BlockUml b : blocks) {
 			final Diagram system = b.getDiagram();
 			final int nbInSystem = system.getNbImages();
@@ -211,26 +201,25 @@ public class SourceStringReader {
 	}
 
 	public DiagramDescription generateDiagramDescription(FileFormatOption fileFormatOption) {
-		return generateDiagramDescription(0, fileFormatOption.withStyle(style));
+		return generateDiagramDescription(0, fileFormatOption);
 	}
 
 	public DiagramDescription generateDiagramDescription(int numImage) {
-		return generateDiagramDescription(numImage, new FileFormatOption(FileFormat.PNG).withStyle(style));
+		return generateDiagramDescription(numImage, new FileFormatOption(FileFormat.PNG));
 	}
 
 	public String getCMapData(int numImage, FileFormatOption fileFormatOption) throws IOException {
-		fileFormatOption = fileFormatOption.withStyle(style);
-		if (blocks.size() == 0) {
+		if (blocks.size() == 0)
 			return null;
-		}
+
 		for (BlockUml b : blocks) {
 			final Diagram system = b.getDiagram();
 			final int nbInSystem = system.getNbImages();
 			if (numImage < nbInSystem) {
 				final ImageData imageData = system.exportDiagram(new NullOutputStream(), numImage, fileFormatOption);
-				if (imageData.containsCMapData()) {
+				if (imageData.containsCMapData())
 					return imageData.getCMapData("plantuml");
-				}
+
 				return null;
 			}
 			numImage -= nbInSystem;
@@ -240,7 +229,6 @@ public class SourceStringReader {
 	}
 
 	public ImageData noStartumlFound(OutputStream os, FileFormatOption fileFormatOption) throws IOException {
-		fileFormatOption = fileFormatOption.withStyle(style);
 		final TextBlockBackcolored error = GraphicStrings.createForError(Arrays.asList("No @startuml/@enduml found"),
 				fileFormatOption.isUseRedForError());
 
