@@ -35,12 +35,12 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.ftile;
 
-import java.awt.geom.Point2D;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 
 public enum SnakeDirection {
 	VERTICAL_THEN_HORIZONTAL, HORIZONTAL_THEN_VERTICAL;
 
-	public static SnakeDirection getDirection(Point2D pt1, Point2D pt2) {
+	public static SnakeDirection getDirection(XPoint2D pt1, XPoint2D pt2) {
 		if (pt1.getX() == pt2.getX()) {
 			return VERTICAL_THEN_HORIZONTAL;
 		}
