@@ -43,6 +43,7 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactory;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactoryDelegator;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
+import net.sourceforge.plantuml.graphic.VerticalAlignment;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
 
 public class FtileFactoryDelegatorAddNote extends FtileFactoryDelegator {
@@ -52,22 +53,23 @@ public class FtileFactoryDelegatorAddNote extends FtileFactoryDelegator {
 	}
 
 	@Override
-	public Ftile addNote(Ftile ftile, Swimlane swimlane, Collection<PositionedNote> notes) {
-		if (notes.size() == 0) {
+	public Ftile addNote(Ftile ftile, Swimlane swimlane, Collection<PositionedNote> notes,
+			VerticalAlignment verticalAlignment) {
+		if (notes.size() == 0)
 			throw new IllegalArgumentException();
-		}
-		// if (notes.size() > 1) {
+
+		// if (notes.size() > 1)
 		// throw new IllegalArgumentException();
-		// }
+
 		ISkinParam skinParam = skinParam();
 		if (ftile == null) {
 			final PositionedNote note = notes.iterator().next();
-			if (note.getColors() != null) {
+			if (note.getColors() != null)
 				skinParam = note.getColors().mute(skinParam);
-			}
+
 			return new FtileNoteAlone(skinParam.shadowing(null), note.getDisplay(), skinParam,
 					note.getType() == NoteType.NOTE, swimlane);
 		}
-		return FtileWithNoteOpale.create(ftile, notes, skinParam, true);
+		return FtileWithNoteOpale.create(ftile, notes, skinParam, true, verticalAlignment);
 	}
 }
