@@ -35,7 +35,6 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact;
 
-import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -52,6 +51,7 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.FtileKilled;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileUtils;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Snake;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vertical.FtileThinSplit;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.Rainbow;
 import net.sourceforge.plantuml.graphic.StringBounder;
@@ -78,7 +78,7 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 		Ftile result = inner;
 		final List<Connection> conns = new ArrayList<>();
 		final Style style = getStyleSignature().getMergedStyle(skinParam().getCurrentStyleBuilder());
-		final Rainbow thinColor = Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle());
+		final Rainbow thinColor = Rainbow.build(style, skinParam().getIHtmlColorSet());
 
 		final Ftile thin = new FtileThinSplit(skinParam(), getThin1Color(thinColor), list99.get(0).getSwimlaneIn());
 		double x = 0;
@@ -93,7 +93,7 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 
 			final LinkRendering inLinkRendering = tmp.getInLinkRendering();
 			final Rainbow rainbow = inLinkRendering
-					.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle()));
+					.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet()));
 
 			conns.add(new ConnectionIn(thin, tmp, x, rainbow));
 			x += dim.getWidth();
@@ -117,7 +117,7 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 		for (Ftile tmp : list99) {
 			final LinkRendering inLinkRendering = tmp.getInLinkRendering();
 			final Rainbow rainbow = inLinkRendering
-					.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle()));
+					.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet()));
 
 			if (rainbow.isInvisible() == false)
 				return thinColor.getColor();
@@ -144,7 +144,7 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 		final Style style = getStyleSignature().getMergedStyle(skinParam().getCurrentStyleBuilder());
 		final LinkRendering inLinkRendering = result.getInLinkRendering();
 		final Rainbow thinColor = inLinkRendering
-				.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle()));
+				.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet()));
 
 		final Ftile out = new FtileThinSplit(skinParam(), thinColor.getColor(), swimlaneOutForStep2());
 		result = new FtileAssemblySimple(result, out);
@@ -164,7 +164,7 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 
 			final LinkRendering outLinkRendering = tmp.getOutLinkRendering();
 			final Rainbow rainbow = outLinkRendering
-					.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet(), skinParam().getThemeStyle()));
+					.getRainbow(Rainbow.build(style, skinParam().getIHtmlColorSet()));
 
 			if (tmp.calculateDimension(getStringBounder()).hasPointOut())
 				conns.add(new ConnectionOut(translate0, tmp, out, x, rainbow, getHeightOfMiddle(inner)));
@@ -211,15 +211,15 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 		public void drawTranslate(UGraphic ug, UTranslate translate1, UTranslate translate2) {
 			ug = ug.apply(UTranslate.dx(x));
 			final FtileGeometry geo = getFtile2().calculateDimension(getStringBounder());
-			final Point2D p1 = new Point2D.Double(geo.getLeft(), 0);
-			final Point2D p2 = new Point2D.Double(geo.getLeft(), geo.getInY());
+			final XPoint2D p1 = new XPoint2D(geo.getLeft(), 0);
+			final XPoint2D p2 = new XPoint2D(geo.getLeft(), geo.getInY());
 
 			Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown());
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
-			final Point2D mp1a = translate1.getTranslated(p1);
-			final Point2D mp2b = translate2.getTranslated(p2);
+			final XPoint2D mp1a = translate1.getTranslated(p1);
+			final XPoint2D mp2b = translate2.getTranslated(p2);
 			final double middle = mp1a.getY() + 4;
 			snake.addPoint(mp1a);
 			snake.addPoint(mp1a.getX(), middle);
@@ -257,8 +257,8 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
-			final Point2D p1 = translate0.getTranslated(new Point2D.Double(geo.getLeft(), geo.getOutY()));
-			final Point2D p2 = translate0.getTranslated(new Point2D.Double(geo.getLeft(), height));
+			final XPoint2D p1 = translate0.getTranslated(new XPoint2D(geo.getLeft(), geo.getOutY()));
+			final XPoint2D p2 = translate0.getTranslated(new XPoint2D(geo.getLeft(), height));
 			snake.addPoint(p1);
 			snake.addPoint(p2);
 			ug.draw(snake);
@@ -271,15 +271,15 @@ public class ParallelBuilderSplit extends AbstractParallelFtilesBuilder {
 			if (geo.hasPointOut() == false)
 				return;
 
-			final Point2D p1 = translate0.getTranslated(new Point2D.Double(geo.getLeft(), geo.getOutY()));
-			final Point2D p2 = translate0.getTranslated(new Point2D.Double(geo.getLeft(), height));
+			final XPoint2D p1 = translate0.getTranslated(new XPoint2D(geo.getLeft(), geo.getOutY()));
+			final XPoint2D p2 = translate0.getTranslated(new XPoint2D(geo.getLeft(), height));
 
 			Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown());
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
-			final Point2D mp1a = translate1.getTranslated(p1);
-			final Point2D mp2b = translate2.getTranslated(p2);
+			final XPoint2D mp1a = translate1.getTranslated(p1);
+			final XPoint2D mp2b = translate2.getTranslated(p2);
 			final double middle = mp2b.getY() - 14;
 			snake.addPoint(mp1a);
 			snake.addPoint(mp1a.getX(), middle);
