@@ -35,10 +35,9 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.gtile;
 
-import java.awt.geom.Point2D;
-
 import net.sourceforge.plantuml.activitydiagram3.ftile.Arrows;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Snake;
+import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -63,10 +62,10 @@ public class GConnectionVerticalDown extends GAbstractConnection {
 	public void drawTranslate(UGraphic ug, UTranslate translate1, UTranslate translate2) {
 		final Snake snake = Snake.create(skinParam(), getInLinkRenderingColor(), Arrows.asToDown()).withLabel(textBlock,
 				HorizontalAlignment.LEFT);
-		final Point2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
-		final Point2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
-		final Point2D mp1a = translate1.getTranslated(p1);
-		final Point2D mp2b = translate2.getTranslated(p2);
+		final XPoint2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
+		final XPoint2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
+		final XPoint2D mp1a = translate1.getTranslated(p1);
+		final XPoint2D mp2b = translate2.getTranslated(p2);
 		final double middle = (mp1a.getY() + mp2b.getY()) / 2.0;
 		snake.addPoint(mp1a);
 		snake.addPoint(mp1a.getX(), middle);
@@ -80,8 +79,8 @@ public class GConnectionVerticalDown extends GAbstractConnection {
 	public void drawU(UGraphic ug) {
 		final Snake snake = Snake.create(skinParam(), getInLinkRenderingColor(), Arrows.asToDown()).withLabel(textBlock,
 				HorizontalAlignment.LEFT);
-		final Point2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
-		final Point2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
+		final XPoint2D p1 = pos1.getTranslated(gpoint1.getPoint2D());
+		final XPoint2D p2 = pos2.getTranslated(gpoint2.getPoint2D());
 		snake.addPoint(p1);
 		snake.addPoint(p2);
 		ug.draw(snake);
@@ -123,8 +122,8 @@ public class GConnectionVerticalDown extends GAbstractConnection {
 //	@Override
 //	public void drawTranslate(UGraphic ug, UTranslate translate1, UTranslate translate2) {
 //		final Snake snake = Snake.create(color, Arrows.asToDown()).withLabel(textBlock, HorizontalAlignment.LEFT);
-//		final Point2D mp1a = translate1.getTranslated(p1);
-//		final Point2D mp2b = translate2.getTranslated(p2);
+//		final XPoint2D mp1a = translate1.getTranslated(p1);
+//		final XPoint2D mp2b = translate2.getTranslated(p2);
 //		final double middle = (mp1a.getY() + mp2b.getY()) / 2.0;
 //		snake.addPoint(mp1a);
 //		snake.addPoint(mp1a.getX(), middle);
