@@ -40,10 +40,9 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlockUtils;
@@ -95,8 +94,8 @@ public class GtileRepeat extends GtileTopDown3 {
 	}
 
 	@Override
-	public Dimension2D calculateDimension(StringBounder stringBounder) {
-		return Dimension2DDouble.delta(super.calculateDimension(stringBounder), SUPP_WIDTH, 0);
+	public XDimension2D calculateDimension(StringBounder stringBounder) {
+		return XDimension2D.delta(super.calculateDimension(stringBounder), SUPP_WIDTH, 0);
 	}
 
 	@Override
