@@ -52,7 +52,6 @@ import net.sourceforge.plantuml.cucadiagram.Ident;
 import net.sourceforge.plantuml.cucadiagram.NamespaceStrategy;
 import net.sourceforge.plantuml.graphic.color.ColorType;
 import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
-import net.sourceforge.plantuml.utils.UniqueSequence;
 
 public class CommandPackageEmpty extends SingleLineCommand2<AbstractEntityDiagram> {
 
@@ -88,7 +87,7 @@ public class CommandPackageEmpty extends SingleLineCommand2<AbstractEntityDiagra
 		final String display;
 		if (arg.get("CODE", 0) == null) {
 			if (StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(arg.get("DISPLAY", 0)).length() == 0) {
-				idShort = "##" + UniqueSequence.getValue();
+				idShort = "##" + diagram.getUniqueSequence();
 				display = null;
 			} else {
 				idShort = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(arg.get("DISPLAY", 0));
@@ -107,7 +106,7 @@ public class CommandPackageEmpty extends SingleLineCommand2<AbstractEntityDiagra
 		final String color = arg.get("COLOR", 0);
 		if (color != null) {
 			p.setSpecificColorTOBEREMOVED(ColorType.BACK,
-					diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), color));
+					diagram.getSkinParam().getIHtmlColorSet().getColor(color));
 		}
 		diagram.endGroup();
 		return CommandExecutionResult.ok();
