@@ -5,12 +5,12 @@
  * (C) Copyright 2009-2023, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
- * 
+ *
  * If you like this project or if you find it useful, you can support us at:
- * 
+ *
  * http://plantuml.com/patreon (only 1$ per month!)
  * http://plantuml.com/paypal
- * 
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,15 +30,13 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.dedication;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 
-import java.io.UnsupportedEncodingException;
-
 public final class TinyHashableString {
 
 	private final String sentence;
@@ -48,11 +46,11 @@ public final class TinyHashableString {
 		this.sentence = sentence;
 	}
 
-	public final String getSentence() {
+	public String getSentence() {
 		return sentence;
 	}
 
-	public final synchronized int tinyHash() throws UnsupportedEncodingException {
+	public synchronized int tinyHash() {
 		if (cachedTinyHash == -1) {
 			cachedTinyHash = Noise.shortHash(sentence.getBytes(UTF_8), Dedication.N.toByteArray());
 		}
