@@ -41,19 +41,28 @@ import java.util.ArrayList;
 import java.util.List;
 
 import net.sourceforge.plantuml.FileFormatOption;
+import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.TitledDiagram;
 import net.sourceforge.plantuml.UmlDiagramType;
+import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.FloatingNote;
+import net.sourceforge.plantuml.command.BlocLines;
+import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.core.UmlSource;
+import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.TextBlockUtils;
+import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 
 public class PSystemEbnf extends TitledDiagram {
 
-	private final List<String> lines = new ArrayList<>();
+	private final List<TextBlockable> expressions = new ArrayList<>();
 
 	public PSystemEbnf(UmlSource source) {
 		super(source, UmlDiagramType.EBNF, null);
@@ -63,8 +72,26 @@ public class PSystemEbnf extends TitledDiagram {
 		return new DiagramDescription("(EBNF)");
 	}
 
-	public void doCommandLine(String line) {
-		lines.add(line);
+	public CommandExecutionResult addBlocLines(BlocLines blines, String commentAbove, String commentBelow) {
+		final boolean isCompact = getPragma().isDefine("compact");
+		final CharIterator it = new CharIteratorImpl(blines);
+		final EbnfExpression tmp1 = EbnfExpression.create(it, isCompact, commentAbove, commentBelow);
+		if (tmp1.isEmpty())
+			return CommandExecutionResult.error("Unparsable expression");
+		expressions.add(tmp1);
+		return CommandExecutionResult.ok();
+
+	}
+
+	public CommandExecutionResult addNote(final Display note, Colors colors) {
+		expressions.add(new TextBlockable() {
+			@Override
+			public TextBlock getUDrawable(ISkinParam skinParam) {
+				final FloatingNote f = FloatingNote.create(note, skinParam, SName.ebnf);
+				return TextBlockUtils.withMargin(f, 0, 0, 5, 15);
+			}
+		});
+		return CommandExecutionResult.ok();
 	}
 
 	@Override
@@ -74,10 +101,19 @@ public class PSystemEbnf extends TitledDiagram {
 	}
 
 	private TextBlockBackcolored getTextBlock() {
-		final List<EbnfSingleExpression> all = EbnfExpressions.build(lines);
-		TextBlock result = all.get(0).getUDrawable(getSkinParam());
-		for (int i = 1; i < all.size(); i++)
-			result = TextBlockUtils.mergeTB(result, all.get(i).getUDrawable(getSkinParam()), HorizontalAlignment.LEFT);
+		if (expressions.size() == 0) {
+			final Style style = ETile.getStyleSignature().getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+			final FontConfiguration fc = style.getFontConfiguration(getSkinParam().getIHtmlColorSet());
+
+			final TextBlock tmp = EbnfEngine.syntaxError(fc, getSkinParam());
+			return TextBlockUtils.addBackcolor(tmp, null);
+		}
+
+		TextBlock result = expressions.get(0).getUDrawable(getSkinParam());
+		for (int i = 1; i < expressions.size(); i++)
+			result = TextBlockUtils.mergeTB(result, expressions.get(i).getUDrawable(getSkinParam()),
+					HorizontalAlignment.LEFT);
 		return TextBlockUtils.addBackcolor(result, null);
 	}
+
 }
