@@ -70,8 +70,7 @@ public class CommandMindMapPlus extends SingleLineCommand2<MindMapDiagram> {
 		final String stringColor = arg.get("BACKCOLOR", 0);
 		HColor backColor = null;
 		if (stringColor != null) {
-			backColor = diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(),
-					stringColor);
+			backColor = diagram.getSkinParam().getIHtmlColorSet().getColor(stringColor);
 		}
 		final boolean direction = type.contains("-") ? false : true;
 		return diagram.addIdea(backColor, type.length() - 1, Display.getWithNewlines(label),
