@@ -48,7 +48,7 @@ public class Stdlib {
 			if (folder == null || folder.info.size() == 0)
 				return null;
 
-			final String data = folder.loadRessource(fullname.substring(last + 1));
+			final String data = folder.loadResource(fullname.substring(last + 1));
 			if (data == null)
 				return null;
 
@@ -74,7 +74,7 @@ public class Stdlib {
 		return result;
 	}
 
-	private String loadRessource(String file) throws IOException {
+	private String loadResource(String file) throws IOException {
 		final SoftReference<String> cached = cache.get(file.toLowerCase());
 		if (cached != null) {
 			final String cachedResult = cached.get();
