@@ -35,22 +35,14 @@
  */
 package net.sourceforge.plantuml.project.draw;
 
-import java.util.Locale;
-import java.util.Map;
-
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.project.LoadPlanable;
+import net.sourceforge.plantuml.project.TimeHeaderParameters;
 import net.sourceforge.plantuml.project.time.Day;
-import net.sourceforge.plantuml.project.time.DayOfWeek;
 import net.sourceforge.plantuml.project.time.MonthYear;
 import net.sourceforge.plantuml.project.time.WeekNumberStrategy;
 import net.sourceforge.plantuml.project.timescale.TimeScaleCompressed;
-import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
 
 public class TimeHeaderWeekly extends TimeHeaderCalendar {
 
@@ -65,12 +57,9 @@ public class TimeHeaderWeekly extends TimeHeaderCalendar {
 		return 16;
 	}
 
-	public TimeHeaderWeekly(WeekNumberStrategy weekNumberStrategy, boolean withCalendarDate, Locale locale, Style timelineStyle,
-			Style closedStyle, double scale, Day calendar, Day min, Day max, LoadPlanable defaultPlan,
-			Map<Day, HColor> colorDays, Map<DayOfWeek, HColor> colorDaysOfWeek, HColorSet colorSet,
-			ThemeStyle themeStyle) {
-		super(locale, timelineStyle, closedStyle, calendar, min, max, defaultPlan, colorDays, colorDaysOfWeek,
-				new TimeScaleCompressed(calendar, scale), colorSet, themeStyle);
+	public TimeHeaderWeekly(TimeHeaderParameters thParam, WeekNumberStrategy weekNumberStrategy,
+			boolean withCalendarDate) {
+		super(thParam, new TimeScaleCompressed(thParam.getStartingDay(), thParam.getScale()));
 		this.weekNumberStrategy = weekNumberStrategy;
 		this.withCalendarDate = withCalendarDate;
 	}
@@ -103,7 +92,7 @@ public class TimeHeaderWeekly extends TimeHeaderCalendar {
 		for (Day wink = min; wink.compareTo(max) < 0; wink = wink.increment()) {
 			final double x1 = getTimeScale().getStartingPosition(wink);
 			if (wink.monthYear().equals(last) == false) {
-				drawVbar(ug, x1, 0, Y_POS_ROW16());
+				drawVbar(ug, x1, 0, Y_POS_ROW16(), false);
 				if (last != null) {
 					printMonth(ug, last, lastChangeMonth, x1);
 				}
@@ -111,7 +100,7 @@ public class TimeHeaderWeekly extends TimeHeaderCalendar {
 				last = wink.monthYear();
 			}
 		}
-		drawVbar(ug, getTimeScale().getEndingPosition(max), 0, Y_POS_ROW16());
+		drawVbar(ug, getTimeScale().getEndingPosition(max), 0, Y_POS_ROW16(), false);
 		final double x1 = getTimeScale().getStartingPosition(max.increment());
 		if (x1 > lastChangeMonth) {
 			printMonth(ug, last, lastChangeMonth, x1);
@@ -121,10 +110,10 @@ public class TimeHeaderWeekly extends TimeHeaderCalendar {
 	private void printSmallVbars(final UGraphic ug, double totalHeightWithoutFooter) {
 		for (Day wink = min; wink.compareTo(max) <= 0; wink = wink.increment()) {
 			if (wink.getDayOfWeek() == weekNumberStrategy.getFirstDayOfWeek()) {
-				drawVbar(ug, getTimeScale().getStartingPosition(wink), Y_POS_ROW16(), totalHeightWithoutFooter);
+				drawVbar(ug, getTimeScale().getStartingPosition(wink), Y_POS_ROW16(), totalHeightWithoutFooter, false);
 			}
 		}
-		drawVbar(ug, getTimeScale().getEndingPosition(max), Y_POS_ROW16(), totalHeightWithoutFooter);
+		drawVbar(ug, getTimeScale().getEndingPosition(max), Y_POS_ROW16(), totalHeightWithoutFooter, false);
 	}
 
 	private void printDaysOfMonth(final UGraphic ug) {
@@ -143,8 +132,8 @@ public class TimeHeaderWeekly extends TimeHeaderCalendar {
 	}
 
 	private void printMonth(UGraphic ug, MonthYear monthYear, double start, double end) {
-		final TextBlock small = getTextBlock(monthYear.shortName(locale), 12, true, openFontColor());
-		final TextBlock big = getTextBlock(monthYear.shortNameYYYY(locale), 12, true, openFontColor());
+		final TextBlock small = getTextBlock(monthYear.shortName(locale()), 12, true, openFontColor());
+		final TextBlock big = getTextBlock(monthYear.shortNameYYYY(locale()), 12, true, openFontColor());
 		printCentered(ug, false, start, end, small, big);
 	}
 
