@@ -36,7 +36,6 @@
 package net.sourceforge.plantuml.salt;
 
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.command.PSystemBasicFactory;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
@@ -48,11 +47,11 @@ public class PSystemSaltFactory extends PSystemBasicFactory<PSystemSalt> {
 	}
 
 	@Override
-	public PSystemSalt initDiagram(ThemeStyle style, UmlSource source, String startLine) {
+	public PSystemSalt initDiagram(UmlSource source, String startLine) {
 		if (getDiagramType() == DiagramType.UML) {
 			return null;
 		} else if (getDiagramType() == DiagramType.SALT) {
-			return new PSystemSalt(style, source);
+			return new PSystemSalt(source);
 		} else {
 			throw new IllegalStateException(getDiagramType().name());
 		}
@@ -60,9 +59,9 @@ public class PSystemSaltFactory extends PSystemBasicFactory<PSystemSalt> {
 	}
 
 	@Override
-	public PSystemSalt executeLine(ThemeStyle style, UmlSource source, PSystemSalt system, String line) {
+	public PSystemSalt executeLine(UmlSource source, PSystemSalt system, String line) {
 		if (system == null && line.replace('\t', ' ').trim().equals("salt")) {
-			return new PSystemSalt(style, source);
+			return new PSystemSalt(source);
 		}
 		if (system == null) {
 			return null;
