@@ -35,15 +35,14 @@
  */
 package net.sourceforge.plantuml.salt.element;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
-
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 
 public interface Element {
 
-	public Dimension2D getPreferredDimension(StringBounder stringBounder, double x, double y);
+	public XDimension2D getPreferredDimension(StringBounder stringBounder, double x, double y);
 
-	public void drawU(UGraphic ug, int zIndex, Dimension2D dimToUse);
+	public void drawU(UGraphic ug, int zIndex, XDimension2D dimToUse);
 
 }
