@@ -35,10 +35,9 @@
  */
 package net.sourceforge.plantuml.salt.element;
 
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
 import java.util.List;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UPixel;
@@ -52,11 +51,11 @@ public class ElementImage extends AbstractElement {
 		this.img = img;
 	}
 
-	public Dimension2D getPreferredDimension(StringBounder stringBounder, double x, double y) {
-		return new Dimension2DDouble(img.get(0).length(), img.size());
+	public XDimension2D getPreferredDimension(StringBounder stringBounder, double x, double y) {
+		return new XDimension2D(img.get(0).length(), img.size());
 	}
 
-	public void drawU(UGraphic ug, int zIndex, Dimension2D dimToUse) {
+	public void drawU(UGraphic ug, int zIndex, XDimension2D dimToUse) {
 		if (zIndex != 0)
 			return;
 
