@@ -35,8 +35,8 @@
  */
 package net.sourceforge.plantuml.sequencediagram.teoz;
 
-import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.real.Real;
+import net.sourceforge.plantuml.sequencediagram.AbstractEvent;
 import net.sourceforge.plantuml.sequencediagram.Event;
 import net.sourceforge.plantuml.sequencediagram.Participant;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -45,16 +45,26 @@ public class EmptyTile extends AbstractTile implements Tile {
 
 	private final double height;
 	private final Tile position;
+	private final YGauge yGauge;
 
-	public EmptyTile(double height, Tile position) {
-		super(((AbstractTile) position).getStringBounder());
+	public EmptyTile(double height, Tile position, YGauge currentY) {
+		super(((AbstractTile) position).getStringBounder(), currentY);
+		if (YGauge.USE_ME)
+			throw new UnsupportedOperationException();
 		this.height = height;
 		this.position = position;
+		this.yGauge = YGauge.create(currentY.getMax(), getPreferredHeight());
+	}
+
+	@Override
+	public YGauge getYGauge() {
+		return yGauge;
 	}
 
 	public void drawU(UGraphic ug) {
 	}
 
+	@Override
 	public double getPreferredHeight() {
 		return height;
 	}
@@ -71,22 +81,10 @@ public class EmptyTile extends AbstractTile implements Tile {
 	}
 
 	public Event getEvent() {
-		return new Event() {
+		return new AbstractEvent() {
 			public boolean dealWith(Participant someone) {
 				return false;
 			}
-
-			public Url getUrl() {
-				return null;
-			}
-
-			public boolean hasUrl() {
-				return false;
-			}
-
-			public boolean isParallel() {
-				return false;
-			}
 		};
 	}
 
