@@ -37,7 +37,7 @@ package net.sourceforge.plantuml.skin.rose;
 
 import net.sourceforge.plantuml.ISkinSimple;
 import net.sourceforge.plantuml.LineBreakStrategy;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.SymbolContext;
@@ -58,7 +58,7 @@ public class ComponentRoseEntity extends AbstractTextualComponent {
 			ISkinSimple spriteContainer) {
 		super(style, stereo, LineBreakStrategy.NONE, 3, 3, 0, spriteContainer, stringsToDisplay, false);
 
-		final SymbolContext biColor = style.getSymbolContext(spriteContainer.getThemeStyle(), getIHtmlColorSet());
+		final SymbolContext biColor = style.getSymbolContext(getIHtmlColorSet());
 
 		this.head = head;
 		this.stickman = new EntityDomain(biColor);
@@ -68,7 +68,7 @@ public class ComponentRoseEntity extends AbstractTextualComponent {
 	protected void drawInternalU(UGraphic ug, Area area) {
 		final TextBlock textBlock = getTextBlock();
 		final StringBounder stringBounder = ug.getStringBounder();
-		final Dimension2D dimStickman = stickman.calculateDimension(stringBounder);
+		final XDimension2D dimStickman = stickman.calculateDimension(stringBounder);
 		final double delta = (getPreferredWidth(stringBounder) - dimStickman.getWidth()) / 2;
 
 		if (head) {
@@ -87,13 +87,13 @@ public class ComponentRoseEntity extends AbstractTextualComponent {
 
 	@Override
 	public double getPreferredHeight(StringBounder stringBounder) {
-		final Dimension2D dimStickman = stickman.calculateDimension(stringBounder);
+		final XDimension2D dimStickman = stickman.calculateDimension(stringBounder);
 		return dimStickman.getHeight() + getTextHeight(stringBounder);
 	}
 
 	@Override
 	public double getPreferredWidth(StringBounder stringBounder) {
-		final Dimension2D dimStickman = stickman.calculateDimension(stringBounder);
+		final XDimension2D dimStickman = stickman.calculateDimension(stringBounder);
 		return Math.max(dimStickman.getWidth(), getTextWidth(stringBounder));
 	}
 
