@@ -72,6 +72,7 @@ public enum SName {
 	destroy, //
 	diamond, //
 	document, //
+	ebnf, //
 	element, //
 	entity, //
 	end, //
@@ -88,12 +89,14 @@ public enum SName {
 	hexagon, //
 	highlight, //
 	interface_, //
+	json,
 	jsonDiagram, //
 	gitDiagram, //
 	label, //
 	leafNode, //
 	legend, //
 	lifeLine, //
+	mainframe, //
 	map, //
 	milestone, //
 	mindmapDiagram, //
@@ -149,6 +152,8 @@ public enum SName {
 	spotException, //
 	spotClass, //
 	spotAbstractClass, //
+	spotMetaClass, //
+	spotStereotype, //
 
 	wbsDiagram, //
 	yamlDiagram; //
