@@ -35,7 +35,6 @@
  */
 package net.sourceforge.plantuml.style;
 
-import net.sourceforge.plantuml.api.ThemeStyle;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorSet;
 
@@ -55,7 +54,7 @@ public class ValueColor extends ValueAbstract {
 	}
 
 	@Override
-	public HColor asColor(ThemeStyle themeStyle, HColorSet set) {
+	public HColor asColor(HColorSet set) {
 		return color;
 	}
 
