@@ -127,8 +127,8 @@ public final class GroupPngMakerActivity {
 		final ISkinParam skinParam = diagram.getSkinParam();
 
 		final DotData dotData = new DotData(group, links, group.getLeafsDirect(), diagram.getUmlDiagramType(),
-				skinParam, new InnerGroupHierarchy(), diagram.getColorMapper(), diagram.getEntityFactory(), false,
-				DotMode.NORMAL, diagram.getNamespaceSeparator(), diagram.getPragma());
+				skinParam, new InnerGroupHierarchy(), diagram.getEntityFactory(), false, DotMode.NORMAL,
+				diagram.getNamespaceSeparator(), diagram.getPragma());
 
 		final GeneralImageBuilder svek2 = new GeneralImageBuilder(false, dotData, diagram.getEntityFactory(),
 				diagram.getSource(), diagram.getPragma(), stringBounder, SName.activityDiagram);
