@@ -42,6 +42,12 @@ import net.sourceforge.plantuml.svek.Side;
 
 public class ExtremityFactoryDoubleLine extends AbstractExtremityFactory implements ExtremityFactory {
 
+	@Override
+	public UDrawable createUDrawable(XPoint2D p0, double angle, Side side) {
+		angle -= Math.PI / 2;
+		return new ExtremityDoubleLine(p0, angle);
+	}
+
 	@Override
 	public UDrawable createUDrawable(XPoint2D p0, XPoint2D p1, XPoint2D p2, Side side) {
 		final double ortho = atan2(p0, p2);
