@@ -39,12 +39,17 @@ import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.awt.geom.XDimension2D;
 import net.sourceforge.plantuml.cucadiagram.ILeaf;
 import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.AbstractEntityImage;
 import net.sourceforge.plantuml.svek.ShapeType;
+import net.sourceforge.plantuml.ugraphic.CopyForegroundColorToBackgroundColor;
 import net.sourceforge.plantuml.ugraphic.UEllipse;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UShape;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class EntityImageAssociationPoint extends AbstractEntityImage {
 
@@ -58,9 +63,16 @@ public class EntityImageAssociationPoint extends AbstractEntityImage {
 		return new XDimension2D(SIZE, SIZE);
 	}
 
+	private Style getStyle() {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.classDiagram, SName.arrow)
+				.withTOBECHANGED(getStereo()).getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+	}
+
 	final public void drawU(UGraphic ug) {
 		final UShape circle = new UEllipse(SIZE, SIZE);
-		ug.apply(HColors.none()).apply(HColors.BLACK.bg()).draw(circle);
+
+		final HColor color = getStyle().value(PName.LineColor).asColor(getSkinParam().getIHtmlColorSet());
+		ug.apply(color).apply(new CopyForegroundColorToBackgroundColor()).draw(circle);
 	}
 
 	public ShapeType getShapeType() {
