@@ -111,7 +111,6 @@ import net.sourceforge.plantuml.tim.stdlib.IsLight;
 import net.sourceforge.plantuml.tim.stdlib.JsonKeyExists;
 import net.sourceforge.plantuml.tim.stdlib.Lighten;
 import net.sourceforge.plantuml.tim.stdlib.LoadJson;
-import net.sourceforge.plantuml.tim.stdlib.LoadJsonLegacy;
 import net.sourceforge.plantuml.tim.stdlib.LogicalNot;
 import net.sourceforge.plantuml.tim.stdlib.Lower;
 import net.sourceforge.plantuml.tim.stdlib.Newline;
@@ -186,7 +185,7 @@ public class TContext {
 		functionsSet.addFunction(new Dec2hex());
 		functionsSet.addFunction(new HslColor());
 		functionsSet.addFunction(new LoadJson());
-		functionsSet.addFunction(new LoadJsonLegacy());
+		// functionsSet.addFunction(new LoadJsonLegacy());
 		functionsSet.addFunction(new Chr());
 		functionsSet.addFunction(new Size());
 		functionsSet.addFunction(new GetJsonKey());
