@@ -47,6 +47,7 @@ import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.json.Json;
 import net.sourceforge.plantuml.json.JsonValue;
 import net.sourceforge.plantuml.json.ParseException;
+import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.SFile;
 import net.sourceforge.plantuml.security.SURL;
 import net.sourceforge.plantuml.tim.EaterException;
@@ -67,24 +68,24 @@ import net.sourceforge.plantuml.tim.expression.TValue;
  * <pre>
  *     &#64; startuml
  *     ' loads a local file
- *     !$JSON_LOCAL_RELATIVE=%loadJSON("file.json")
+ *     !$JSON_LOCAL_RELATIVE=%load_json("file.json")
  *
  *     ' loads a local file from an absolute file path
- *     !$JSON_LOCAL_ABS=%loadJSON("c:/loaded/data/file.json")
+ *     !$JSON_LOCAL_ABS=%load_json("c:/loaded/data/file.json")
  *
  *     ' tries to load a local file and returns an empty JSON
- *     !$JSON_LOCAL_REL_EMPTY=%loadJSON("file-not-existing.json")
+ *     !$JSON_LOCAL_REL_EMPTY=%load_json("file-not-existing.json")
  *
  *     ' tries to load a local file and returns an default JSON
  *     !$DEF_JSON={"status":"No data found"}
- *     !$JSON_LOCAL_REL_DEF=%loadJSON("file-not-existing.json", $DEF_JSON)
+ *     !$JSON_LOCAL_REL_DEF=%load_json("file-not-existing.json", $DEF_JSON)
  *
  *     ' loads a local file with a specific charset (default is UTF-8)
- *     !$JSON_LOCAL_RELATIVE_CHARSET=%loadJSON("file.json", "{}", "iso-8859-1")
+ *     !$JSON_LOCAL_RELATIVE_CHARSET=%load_json("file.json", "{}", "iso-8859-1")
  *
  *     ' loads a remote JSON from an endpoint (and default, if not reachable)
  *     !$STATUS_NO_CONNECTION={"status": "No connection"}
- *     !$JSON_REMOTE_DEF=%loadJSON("https://localhost:7778/management/health", $STATUS_NO_CONNECTION)
+ *     !$JSON_REMOTE_DEF=%load_json("https://localhost:7778/management/health", $STATUS_NO_CONNECTION)
  *     status -> $JSON_REMOTE_DEF.status
  *     &#64; enduml
  * </pre>
@@ -98,7 +99,7 @@ public class LoadJson extends SimpleReturnFunction {
 	private static final String VALUE_DEFAULT_DEFAULT = "{}";
 
 	public TFunctionSignature getSignature() {
-		return new TFunctionSignature("%loadJSON", 3);
+		return new TFunctionSignature("%load_json", 3);
 	}
 
 	public boolean canCover(int nbArg, Set<String> namedArgument) {
@@ -116,10 +117,10 @@ public class LoadJson extends SimpleReturnFunction {
 			JsonValue jsonValue = Json.parse(data);
 			return TValue.fromJson(jsonValue);
 		} catch (ParseException pe) {
-			pe.printStackTrace();
+			Logme.error(pe);
 			throw EaterException.unlocated("JSON parse issue in source " + path + " on location " + pe.getLocation());
 		} catch (UnsupportedEncodingException e) {
-			e.printStackTrace();
+			Logme.error(e);
 			throw EaterException.unlocated("JSON encoding issue in source " + path + ": " + e.getMessage());
 		}
 	}
@@ -176,7 +177,7 @@ public class LoadJson extends SimpleReturnFunction {
 					byteData = out.toByteArray();
 				}
 			} catch (IOException e) {
-				e.printStackTrace();
+				Logme.error(e);
 				throw EaterException.located("load JSON: Cannot read file " + path + ". " + e.getMessage());
 			}
 		}
