@@ -93,10 +93,8 @@ public abstract class Player implements TimeProjected {
 	final protected SymbolContext getContext() {
 
 		final Style style = getStyleSignature().getMergedStyle(skinParam.getCurrentStyleBuilder());
-		final HColor lineColor = style.value(PName.LineColor).asColor(skinParam.getThemeStyle(),
-				skinParam.getIHtmlColorSet());
-		final HColor backgroundColor = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
-				skinParam.getIHtmlColorSet());
+		final HColor lineColor = style.value(PName.LineColor).asColor(skinParam.getIHtmlColorSet());
+		final HColor backgroundColor = style.value(PName.BackGroundColor).asColor(skinParam.getIHtmlColorSet());
 
 		return new SymbolContext(backgroundColor, lineColor).withStroke(getStroke());
 	}
