@@ -34,7 +34,6 @@
  */
 package net.sourceforge.plantuml.timingdiagram;
 
-import java.awt.geom.Rectangle2D;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.math.BigDecimal;
@@ -46,12 +45,11 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
-import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.UmlDiagram;
 import net.sourceforge.plantuml.UmlDiagramType;
-import net.sourceforge.plantuml.api.ThemeStyle;
-import net.sourceforge.plantuml.awt.geom.Dimension2D;
+import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.awt.geom.XRectangle2D;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
@@ -96,8 +94,8 @@ public class TimingDiagram extends UmlDiagram implements Clocks {
 		return new DiagramDescription("(Timing Diagram)");
 	}
 
-	public TimingDiagram(ThemeStyle style, UmlSource source) {
-		super(style, source, UmlDiagramType.TIMING, null);
+	public TimingDiagram(UmlSource source) {
+		super(source, UmlDiagramType.TIMING, null);
 	}
 
 	@Override
@@ -114,14 +112,14 @@ public class TimingDiagram extends UmlDiagram implements Clocks {
 				drawInternal(ug);
 			}
 
-			public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
+			public XRectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
 				return null;
 			}
 
-			public Dimension2D calculateDimension(StringBounder stringBounder) {
+			public XDimension2D calculateDimension(StringBounder stringBounder) {
 				final double withBeforeRuler = getPart1MaxWidth(stringBounder);
 				final double totalWith = withBeforeRuler + ruler.getWidth() + marginX1 + marginX2;
-				return new Dimension2DDouble(totalWith, getHeightTotal(stringBounder));
+				return new XDimension2D(totalWith, getHeightTotal(stringBounder));
 			}
 
 			public MinMax getMinMax(StringBounder stringBounder) {
@@ -140,7 +138,7 @@ public class TimingDiagram extends UmlDiagram implements Clocks {
 
 	private HColor black() {
 		final Style style = getStyleSignature().getMergedStyle(getSkinParam().getCurrentStyleBuilder());
-		return style.value(PName.LineColor).asColor(getSkinParam().getThemeStyle(), getSkinParam().getIHtmlColorSet());
+		return style.value(PName.LineColor).asColor(getSkinParam().getIHtmlColorSet());
 
 	}
 
