@@ -24,6 +24,8 @@ import java.util.Vector;
 import javax.imageio.event.IIOReadProgressListener;
 import javax.imageio.stream.ImageInputStream;
 
+import net.sourceforge.plantuml.log.Logme;
+
 
 public class VP8Frame {
 	private static int BLOCK_TYPES = 4;
@@ -1050,7 +1052,7 @@ public class VP8Frame {
 			this.coefProbs=Globals.getDefaultCoefProbs();
 			tokenBoolDecoders = new Vector<>();
 		} catch (IOException e) {
-			e.printStackTrace();
+			Logme.error(e);
 		}
 	}
 }
